@@ -1,3 +1,5 @@
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+
 
 /* Define if gethostname () must be declared. */
 #undef NEED_DECLARATION_GETHOSTNAME
@@ -122,7 +124,6 @@
 #undef HAVE_LIBZ
 #undef HAVE_LIBPNG
 #undef HAVE_GMP2_INCLUDE_DIR
-#undef HAVE_GUILE
 
 #undef ssize_t
 #undef u_int64_t
@@ -131,8 +132,6 @@
 #undef HAVE_GLIBTOP_MACHINE_H
 
 #undef GLIBTOP_NAMES
-#undef GLIBTOP_GUILE
-#undef GLIBTOP_GUILE_NAMES
 #undef GLIBTOP_EXAMPLES
 #undef GLIBTOP_INODEDB
 
@@ -151,6 +150,9 @@
 #undef LIBGTOP_ENABLE_DEBUG
 #undef LIBGTOP_FATAL_WARNINGS
 
+/* Define to use glib's malloc. */
+#undef LIBGTOP_USE_GLIB_MALLOC
+
 /* Same as LINUX_VERSION_CODE either from <linux/version.h> or from
  * the running kernel (if we don't have configured kernel sources).
  */
@@ -167,3 +169,7 @@
 
 /* Define if you have the <sys/procfs.h> header file */
 #undef HAVE_SYS_PROCFS_H
+
+/* Define if you have the libxml library */
+#undef HAVE_LIBXML
+
