@@ -1,3 +1,5 @@
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+
 /* $Id$ */
 
 /* Copyright (C) 1998-99 Martin Baulig
@@ -34,38 +36,38 @@
 #include <glibtop_server.h>
 #include <glibtop/types.h>
 
-#ifdef HAVE_GLIBTOP_MACHINE_H
-#include <glibtop_machine.h>
-#endif
+BEGIN_LIBGTOP_DECLS
 
-typedef struct _glibtop		glibtop;
+typedef struct _glibtop			glibtop;
+typedef struct _glibtop_server_private	glibtop_server_private;
 
 #include <glibtop/sysdeps.h>
+#include <glibtop/errors.h>
+
+#ifdef _IN_LIBGTOP
+#include <glibtop-server-private.h>
+#endif
 
 struct _glibtop
 {
-	unsigned flags;
-	unsigned method;		/* Server Method */
-	unsigned error_method;		/* Error Method */
-#ifdef HAVE_GLIBTOP_MACHINE_H
-	glibtop_machine machine;	/* Machine dependent data */
-#endif
-	int input [2];			/* Pipe client <- server */
-	int output [2];			/* Pipe client -> server */
-	int socket;			/* Accepted connection of a socket */
-	int ncpu;			/* Number of CPUs, zero if single-processor */
-	unsigned long os_version_code;	/* Version code of the operating system */
-	const char *name;		/* Program name for error messages */
-	const char *server_command;	/* Command used to invoke server */
-	const char *server_host;	/* Host the server should run on */
-	const char *server_user;	/* Name of the user on the target host */
-	const char *server_rsh;		/* Command used to connect to the target host */
-	unsigned long features;		/* Server is required for this features */
-	unsigned long server_port;	/* Port on which daemon is listening */
-	glibtop_sysdeps sysdeps;	/* Detailed feature list */
-	glibtop_sysdeps required;	/* Required feature list */
-	glibtop_sysdeps wanted;		/* We only want this features */
-	pid_t pid;			/* PID of the server */
+    int refcount;		/* Reference count */
+    unsigned flags;
+    unsigned method;		/* Server Method */
+    unsigned error_method;	/* Error Method */
+    int ncpu;			/* Number of CPUs, zero if single-processor */
+    unsigned long os_version_code;	/* Version code of the operating system */
+    const char *name;		/* Program name for error messages */
+    const char *server_command;	/* Command used to invoke server */
+    const char *server_host;	/* Host the server should run on */
+    const char *server_user;	/* Name of the user on the target host */
+    const char *server_rsh;	/* Command used to connect to the target host */
+    unsigned long features;	/* Server is required for this features */
+    unsigned long server_port;	/* Port on which daemon is listening */
+    glibtop_sysdeps sysdeps;	/* Detailed feature list */
+    glibtop_sysdeps required;	/* Required feature list */
+    glibtop_sysdeps wanted;	/* We only want this features */
+    glibtop_server_private *_priv;	/* Private data */
+    unsigned glibtop_errno;
 };
 
 extern glibtop *glibtop_global_server;
@@ -86,24 +88,12 @@ glibtop_init_s (glibtop **server_ptr,
 		unsigned long features,
 		unsigned flags);
 
-#ifdef GLIBTOP_GUILE
+void
+glibtop_server_ref (glibtop *server);
 
-/* You need to link with -lgtop_guile to get this stuff here. */
+void
+glibtop_server_unref (glibtop *server);
 
-void glibtop_boot_guile (void);
-
-#endif
-
-#ifdef GLIBTOP_GUILE_NAMES
-
-/* You need to link with -lgtop_guile_names to get this stuff here. */
-
-void glibtop_boot_guile_names (void);
-
-#ifndef GLIBTOP_NAMES
-#define GLIBTOP_NAMES
-#endif
-
-#endif
+END_LIBGTOP_DECLS
 
 #endif
