@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
 
-/* $Id: cpu.h,v 1.17 1999/04/18 11:47:53 martin Exp $ */
+/* $Id$ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -38,12 +38,12 @@ BEGIN_LIBGTOP_DECLS
 #define GLIBTOP_CPU_IDLE	4
 #define GLIBTOP_CPU_FREQUENCY	5
 
-#define GLIBTOP_XCPU_TOTAL	6
-#define GLIBTOP_XCPU_USER	7
-#define GLIBTOP_XCPU_NICE	8
-#define GLIBTOP_XCPU_SYS	9
-#define GLIBTOP_XCPU_IDLE	10
-#define GLIBTOP_XCPU_FLAGS	11
+#define GLIBTOP_CPU_XCPU_TOTAL	6
+#define GLIBTOP_CPU_XCPU_USER	7
+#define GLIBTOP_CPU_XCPU_NICE	8
+#define GLIBTOP_CPU_XCPU_SYS	9
+#define GLIBTOP_CPU_XCPU_IDLE	10
+#define GLIBTOP_CPU_XCPU_FLAGS	11
 
 #define GLIBTOP_MAX_CPU		12
 
@@ -58,12 +58,12 @@ struct _glibtop_cpu
 	sys,				/* GLIBTOP_CPU_SYS		*/
 	idle,				/* GLIBTOP_CPU_IDLE		*/
 	frequency,			/* GLIBTOP_CPU_FREQUENCY	*/
-	xcpu_total [GLIBTOP_NCPU],	/* GLIBTOP_XCPU_TOTAL		*/
-	xcpu_user [GLIBTOP_NCPU],	/* GLIBTOP_XCPU_USER		*/
-	xcpu_nice [GLIBTOP_NCPU],	/* GLIBTOP_XCPU_NICE		*/
-	xcpu_sys  [GLIBTOP_NCPU],	/* GLIBTOP_XCPU_SYS		*/
-	xcpu_idle [GLIBTOP_NCPU],	/* GLIBTOP_XCPU_IDLE		*/
-	xcpu_flags;			/* GLIBTOP_XCPU_FLAGS		*/
+	xcpu_total [GLIBTOP_NCPU],	/* GLIBTOP_CPU_XCPU_TOTAL	*/
+	xcpu_user [GLIBTOP_NCPU],	/* GLIBTOP_CPU_XCPU_USER	*/
+	xcpu_nice [GLIBTOP_NCPU],	/* GLIBTOP_CPU_XCPU_NICE	*/
+	xcpu_sys  [GLIBTOP_NCPU],	/* GLIBTOP_CPU_XCPU_SYS		*/
+	xcpu_idle [GLIBTOP_NCPU],	/* GLIBTOP_CPU_XCPU_IDLE	*/
+	xcpu_flags;			/* GLIBTOP_CPU_XCPU_FLAGS	*/
 };
 
 #define glibtop_get_cpu(cpu)	glibtop_get_cpu_l(glibtop_global_server, cpu)
@@ -74,14 +74,14 @@ struct _glibtop_cpu
 #define glibtop_get_cpu_r	glibtop_get_cpu_s
 #endif
 
-void glibtop_get_cpu_l (glibtop *server, glibtop_cpu *buf);
+int glibtop_get_cpu_l (glibtop *server, glibtop_cpu *buf);
 
 #if GLIBTOP_SUID_CPU
-void glibtop_init_cpu_p (glibtop *server);
-void glibtop_get_cpu_p (glibtop *server, glibtop_cpu *buf);
+int glibtop_init_cpu_p (glibtop *server);
+int glibtop_get_cpu_p (glibtop *server, glibtop_cpu *buf);
 #else
-void glibtop_init_cpu_s (glibtop *server);
-void glibtop_get_cpu_s (glibtop *server, glibtop_cpu *buf);
+int glibtop_init_cpu_s (glibtop *server);
+int glibtop_get_cpu_s (glibtop *server, glibtop_cpu *buf);
 #endif
 
 #ifdef GLIBTOP_NAMES
