@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
 
-/* $Id: limits.h,v 1.4 1999/05/28 12:01:56 martin Exp $ */
+/* $Id$ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -39,6 +39,15 @@ BEGIN_LIBGTOP_DECLS
 /* Maximum length of a mountpoint/device name in glibtop_mountlist. */
 #define GLIBTOP_MOUNTENTRY_LEN	79
 
+/* Maximum length of a network interface name. */
+#define GLIBTOP_INTERFACE_LEN	32
+
+/* This is ((u_int64_t)-1) */
+#define GLIBTOP_UNLIMITED	(~(u_int64_t)0)
+
+/* Maximum length of a backend name. */
+#define GLIBTOP_BACKEND_NAME_LEN	40
+
 END_LIBGTOP_DECLS
 
 #endif
