@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
 
-/* $Id: mem.h,v 1.15 1999/03/30 14:23:12 martin Exp $ */
+/* $Id$ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -65,14 +65,14 @@ struct _glibtop_mem
 #define glibtop_get_mem_r		glibtop_get_mem_s
 #endif
 
-void glibtop_get_mem_l (glibtop *server, glibtop_mem *buf);
+int glibtop_get_mem_l (glibtop *server, glibtop_mem *buf);
 
 #if GLIBTOP_SUID_MEM
-void glibtop_init_mem_p (glibtop *server);
-void glibtop_get_mem_p (glibtop *server, glibtop_mem *buf);
+int glibtop_init_mem_p (glibtop *server);
+int glibtop_get_mem_p (glibtop *server, glibtop_mem *buf);
 #else
-void glibtop_init_mem_s (glibtop *server);
-void glibtop_get_mem_s (glibtop *server, glibtop_mem *buf);
+int glibtop_init_mem_s (glibtop *server);
+int glibtop_get_mem_s (glibtop *server, glibtop_mem *buf);
 #endif
 
 #ifdef GLIBTOP_NAMES
