@@ -85,14 +85,14 @@ struct _glibtop_proc_kernel
 #define glibtop_get_proc_kernel_r	glibtop_get_proc_kernel_s
 #endif
 
-void glibtop_get_proc_kernel_l (glibtop *server, glibtop_proc_kernel *buf, pid_t pid);
+int glibtop_get_proc_kernel_l (glibtop *server, glibtop_proc_kernel *buf, pid_t pid);
 
 #if GLIBTOP_SUID_PROC_KERNEL
-void glibtop_init_proc_kernel_p (glibtop *server);
-void glibtop_get_proc_kernel_p (glibtop *server, glibtop_proc_kernel *buf, pid_t pid);
+int glibtop_init_proc_kernel_p (glibtop *server);
+int glibtop_get_proc_kernel_p (glibtop *server, glibtop_proc_kernel *buf, pid_t pid);
 #else
-void glibtop_init_proc_kernel_s (glibtop *server);
-void glibtop_get_proc_kernel_s (glibtop *server, glibtop_proc_kernel *buf, pid_t pid);
+int glibtop_init_proc_kernel_s (glibtop *server);
+int glibtop_get_proc_kernel_s (glibtop *server, glibtop_proc_kernel *buf, pid_t pid);
 #endif
 
 #ifdef GLIBTOP_NAMES
