@@ -50,14 +50,16 @@ BEGIN_LIBGTOP_DECLS
 #define GLIBTOP_SYSDEPS_PROC_MAP	17
 #define GLIBTOP_SYSDEPS_MOUNTLIST	18
 #define GLIBTOP_SYSDEPS_FSUSAGE		19
-#define GLIBTOP_SYSDEPS_NETLOAD		20
-#define GLIBTOP_SYSDEPS_PPP		21
+#define GLIBTOP_SYSDEPS_INTERFACE_NAMES	20
+#define GLIBTOP_SYSDEPS_NETINFO		21
+#define GLIBTOP_SYSDEPS_NETLOAD		22
+#define GLIBTOP_SYSDEPS_PPP		23
 
-#define GLIBTOP_MAX_SYSDEPS		24
+#define GLIBTOP_MAX_SYSDEPS		26
 
 #define GLIBTOP_SYSDEPS_ALL		((1 << GLIBTOP_MAX_SYSDEPS) - 1)
 
-typedef void (*glibtop_init_func_t) (glibtop *);
+typedef int (*glibtop_init_func_t) (glibtop *);
 extern glibtop_init_func_t _glibtop_init_hook_s [];
 extern glibtop_init_func_t _glibtop_init_hook_p [];
 
@@ -88,6 +90,8 @@ struct _glibtop_sysdeps
 	proc_map,		/* glibtop_proc_map	*/
 	mountlist,		/* glibtop_mountlist	*/
 	fsusage,		/* glibtop_fsusage	*/
+	interface_names,	/* glibtop_interface_names	*/
+	netinfo,		/* glibtop_netinfo	*/
 	netload,		/* glibtop_netload	*/
 	ppp;			/* glibtop_ppp		*/
 };
