@@ -50,6 +50,8 @@
 #include <glibtop/fsusage.h>
 
 #include <glibtop/netload.h>
+#include <glibtop/netinfo.h>
+#include <glibtop/interfaces.h>
 #include <glibtop/ppp.h>
 
 BEGIN_LIBGTOP_DECLS
@@ -66,7 +68,7 @@ union _glibtop_union
     glibtop_shm_limits		shm_limits;
     glibtop_msg_limits		msg_limits;
     glibtop_sem_limits		sem_limits;
-    glibtop_proclist		proclist;
+    glibtop_array		proclist;
     glibtop_proc_state		proc_state;
     glibtop_proc_uid		proc_uid;
     glibtop_proc_mem		proc_mem;
@@ -74,10 +76,12 @@ union _glibtop_union
     glibtop_proc_signal		proc_signal;
     glibtop_proc_kernel		proc_kernel;
     glibtop_proc_segment	proc_segment;
-    glibtop_proc_args		proc_args;
-    glibtop_proc_map		proc_map;
-    glibtop_mountlist		mountlist;
+    glibtop_array		proc_args;
+    glibtop_array		proc_map;
+    glibtop_array		mountlist;
     glibtop_fsusage		fsusage;
+    glibtop_array		interface_names;
+    glibtop_netinfo		netinfo;
     glibtop_netload		netload;
     glibtop_ppp			ppp;
 };
