@@ -1,4 +1,6 @@
-/* $Id: msg_limits.c,v 1.11 1999/05/06 21:33:43 martin Exp $ */
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+
+/* $Id$ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -30,16 +32,20 @@
 #if (defined __bsdi__) && (_BSDI_VERSION < 199700)
 /* Older versions of BSDI don't seem to have this. */
 
-void
+int
 glibtop_init_msg_limits_p (glibtop *server)
-{ }
+{
+    return 0;
+}
 
-void
+int
 glibtop_get_msg_limits_p (glibtop *server, glibtop_msg_limits *buf)
 {
-        glibtop_init_p (server, (1L << GLIBTOP_SYSDEPS_MSG_LIMITS), 0);
+    glibtop_init_p (server, (1L << GLIBTOP_SYSDEPS_MSG_LIMITS), 0);
 
-        memset (buf, 0, sizeof (glibtop_msg_limits));
+    memset (buf, 0, sizeof (glibtop_msg_limits));
+
+    return 0;
 }
 
 #else
@@ -56,9 +62,9 @@ glibtop_get_msg_limits_p (glibtop *server, glibtop_msg_limits *buf)
 #include <sys/msg.h>
 
 static const unsigned long _glibtop_sysdeps_msg_limits =
-(1L << GLIBTOP_IPC_MSGMAX) + (1L << GLIBTOP_IPC_MSGMNI) +
-(1L << GLIBTOP_IPC_MSGMNB) + (1L << GLIBTOP_IPC_MSGTQL) +
-(1L << GLIBTOP_IPC_MSGSSZ);
+(1L << GLIBTOP_MSG_LIMITS_MSGMAX) + (1L << GLIBTOP_MSG_LIMITS_MSGMNI) +
+(1L << GLIBTOP_MSG_LIMITS_MSGMNB) + (1L << GLIBTOP_MSG_LIMITS_MSGTQL) +
+(1L << GLIBTOP_MSG_LIMITS_MSGSSZ);
 
 /* The values in this structure never change at runtime, so we only
  * read it once during initialization. We have to use the name `_msginfo'
@@ -67,48 +73,52 @@ static struct msginfo _msginfo;
   
 /* nlist structure for kernel access */
 static struct nlist nlst [] = {
-	{ "_msginfo" },
-	{ 0 }
+    { "_msginfo" },
+    { 0 }
 };
 
 /* Init function. */
 
-void
+int
 glibtop_init_msg_limits_p (glibtop *server)
 {
-	if (kvm_nlist (server->machine.kd, nlst) != 0) {
-		glibtop_warn_io_r (server, "kvm_nlist (msg_limits)");
-		return;
-	}
+    if (kvm_nlist (server->_priv->machine.kd, nlst) != 0) {
+	glibtop_warn_io_r (server, "kvm_nlist (msg_limits)");
+	return -1;
+    }
 	
-	if (kvm_read (server->machine.kd, nlst [0].n_value,
-		      &_msginfo, sizeof (_msginfo)) != sizeof (_msginfo)) {
-		glibtop_warn_io_r (server, "kvm_read (msginfo)");
-		return;
-	}
+    if (kvm_read (server->_priv->machine.kd, nlst [0].n_value,
+		  &_msginfo, sizeof (_msginfo)) != sizeof (_msginfo)) {
+	glibtop_warn_io_r (server, "kvm_read (msginfo)");
+	return -1;
+    }
 
-	server->sysdeps.msg_limits = _glibtop_sysdeps_msg_limits;
+    server->sysdeps.msg_limits = _glibtop_sysdeps_msg_limits;
+
+    return 0;
 }
 
 /* Provides information about sysv ipc limits. */
 
-void
+int
 glibtop_get_msg_limits_p (glibtop *server, glibtop_msg_limits *buf)
 {
-	glibtop_init_p (server, (1L << GLIBTOP_SYSDEPS_MSG_LIMITS), 0);
+    glibtop_init_p (server, (1L << GLIBTOP_SYSDEPS_MSG_LIMITS), 0);
 	
-	memset (buf, 0, sizeof (glibtop_msg_limits));
+    memset (buf, 0, sizeof (glibtop_msg_limits));
 
-	if (server->sysdeps.msg_limits == 0)
-		return;
+    if (server->sysdeps.msg_limits == 0)
+	return -1;
 
-	buf->msgmax = _msginfo.msgmax;
-	buf->msgmni = _msginfo.msgmni;
-	buf->msgmnb = _msginfo.msgmnb;
-	buf->msgtql = _msginfo.msgtql;
-	buf->msgssz = _msginfo.msgtql;
+    buf->msgmax = _msginfo.msgmax;
+    buf->msgmni = _msginfo.msgmni;
+    buf->msgmnb = _msginfo.msgmnb;
+    buf->msgtql = _msginfo.msgtql;
+    buf->msgssz = _msginfo.msgtql;
 	
-	buf->flags = _glibtop_sysdeps_msg_limits; 
+    buf->flags = _glibtop_sysdeps_msg_limits; 
+
+    return 0;
 }
 
 #endif /* either a newer BSDI or no BSDI at all. */
