@@ -1,4 +1,6 @@
-/* $Id: netload.c,v 1.10 1999/05/06 21:33:45 martin Exp $ */
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+
+/* $Id$ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -39,10 +41,6 @@
 #include <netinet/in_var.h>
 
 static const unsigned long _glibtop_sysdeps_netload =
-(1L << GLIBTOP_NETLOAD_IF_FLAGS) +
-(1L << GLIBTOP_NETLOAD_MTU) +
-(1L << GLIBTOP_NETLOAD_SUBNET) +
-(1L << GLIBTOP_NETLOAD_ADDRESS) +
 (1L << GLIBTOP_NETLOAD_PACKETS_IN) +
 (1L << GLIBTOP_NETLOAD_PACKETS_OUT) +
 (1L << GLIBTOP_NETLOAD_PACKETS_TOTAL) +
@@ -62,20 +60,23 @@ static struct nlist nlst [] = {
 
 /* Init function. */
 
-void
+int
 glibtop_init_netload_p (glibtop *server)
 {
     server->sysdeps.netload = _glibtop_sysdeps_netload;
 
-    if (kvm_nlist (server->machine.kd, nlst) != 0)
+    if (kvm_nlist (server->_priv->machine.kd, nlst) != 0)
 	glibtop_error_io_r (server, "kvm_nlist");
+
+    return 0;
 }
 
 /* Provides Network statistics. */
 
-void
+int
 glibtop_get_netload_p (glibtop *server, glibtop_netload *buf,
-		       const char *interface)
+		       const char *interface, unsigned transport,
+		       unsigned protocol)
 {
     struct ifnet ifnet;
     u_long ifnetaddr, ifnetfound, ifaddraddr;
@@ -91,7 +92,7 @@ glibtop_get_netload_p (glibtop *server, glibtop_netload *buf,
 	
     memset (buf, 0, sizeof (glibtop_netload));
 
-    if (kvm_read (server->machine.kd, nlst [0].n_value,
+    if (kvm_read (server->_priv->machine.kd, nlst [0].n_value,
 		  &ifnetaddr, sizeof (ifnetaddr)) != sizeof (ifnetaddr))
 	glibtop_error_io_r (server, "kvm_read (ifnet)");
     
@@ -103,14 +104,14 @@ glibtop_get_netload_p (glibtop *server, glibtop_netload *buf,
 	if (ifaddraddr == 0) {
 	    ifnetfound = ifnetaddr;
 
-	    if (kvm_read (server->machine.kd, ifnetaddr, &ifnet,
+	    if (kvm_read (server->_priv->machine.kd, ifnetaddr, &ifnet,
 			  sizeof (ifnet)) != sizeof (ifnet))
-		    glibtop_error_io_r (server, "kvm_read (ifnetaddr)");
+		glibtop_error_io_r (server, "kvm_read (ifnetaddr)");
 
 #if defined(__FreeBSD__) || defined(__bsdi__)
-	    if (kvm_read (server->machine.kd, (u_long) ifnet.if_name,
+	    if (kvm_read (server->_priv->machine.kd, (u_long) ifnet.if_name,
 			  tname, 16) != 16)
-		    glibtop_error_io_r (server, "kvm_read (if_name)");
+		glibtop_error_io_r (server, "kvm_read (if_name)");
 #else
 	    strncpy (tname, ifnet.if_xname, 16);
 	    tname [15] = 0;
@@ -126,7 +127,7 @@ glibtop_get_netload_p (glibtop *server, glibtop_netload *buf,
 	}
 
 	if (ifaddraddr) {
-	    if ((kvm_read (server->machine.kd, ifaddraddr, &ifaddr,
+	    if ((kvm_read (server->_priv->machine.kd, ifaddraddr, &ifaddr,
 			   sizeof (ifaddr)) != sizeof (ifaddr)))
 		glibtop_error_io_r (server, "kvm_read (ifaddraddr)");
 	
@@ -137,46 +138,6 @@ glibtop_get_netload_p (glibtop *server, glibtop_netload *buf,
 	    if (!strcmp (interface, tname) && (sa->sa_family == AF_INET)) {
 		sin = (struct sockaddr_in *)sa;
 
-		if (ifnet.if_flags & IFF_UP)
-			buf->if_flags |= GLIBTOP_IF_FLAGS_UP;
-		if (ifnet.if_flags & IFF_BROADCAST)
-			buf->if_flags |= GLIBTOP_IF_FLAGS_BROADCAST;
-		if (ifnet.if_flags & IFF_DEBUG)
-			buf->if_flags |= GLIBTOP_IF_FLAGS_DEBUG;
-		if (ifnet.if_flags & IFF_LOOPBACK)
-			buf->if_flags |= GLIBTOP_IF_FLAGS_LOOPBACK;
-		if (ifnet.if_flags & IFF_POINTOPOINT)
-			buf->if_flags |= GLIBTOP_IF_FLAGS_POINTOPOINT;
-		if (ifnet.if_flags & IFF_RUNNING)
-			buf->if_flags |= GLIBTOP_IF_FLAGS_RUNNING;
-		if (ifnet.if_flags & IFF_NOARP)
-			buf->if_flags |= GLIBTOP_IF_FLAGS_NOARP;
-		if (ifnet.if_flags & IFF_PROMISC)
-			buf->if_flags |= GLIBTOP_IF_FLAGS_PROMISC;
-		if (ifnet.if_flags & IFF_ALLMULTI)
-			buf->if_flags |= GLIBTOP_IF_FLAGS_ALLMULTI;
-		if (ifnet.if_flags & IFF_OACTIVE)
-			buf->if_flags |= GLIBTOP_IF_FLAGS_OACTIVE;
-		if (ifnet.if_flags & IFF_SIMPLEX)
-			buf->if_flags |= GLIBTOP_IF_FLAGS_SIMPLEX;
-		if (ifnet.if_flags & IFF_LINK0)
-			buf->if_flags |= GLIBTOP_IF_FLAGS_LINK0;
-		if (ifnet.if_flags & IFF_LINK1)
-			buf->if_flags |= GLIBTOP_IF_FLAGS_LINK1;
-		if (ifnet.if_flags & IFF_LINK2)
-			buf->if_flags |= GLIBTOP_IF_FLAGS_LINK2;
-#ifdef __FreeBSD__
-		if (ifnet.if_flags & IFF_ALTPHYS)
-			buf->if_flags |= GLIBTOP_IF_FLAGS_ALTPHYS;
-#endif
-		if (ifnet.if_flags & IFF_MULTICAST)
-			buf->if_flags |= GLIBTOP_IF_FLAGS_MULTICAST;
-
-		buf->subnet = htonl (ifaddr.in.ia_subnet);
-		buf->address = sin->sin_addr.s_addr;
-
-		buf->mtu = ifnet.if_mtu;
-
 		buf->packets_in = ifnet.if_ipackets;
 		buf->packets_out = ifnet.if_opackets;
 		buf->packets_total = buf->packets_in + buf->packets_out;
@@ -191,7 +152,7 @@ glibtop_get_netload_p (glibtop *server, glibtop_netload *buf,
 
 		buf->collisions = ifnet.if_collisions;
 		buf->flags = _glibtop_sysdeps_netload;
-		return;
+		return -1;
 	    }
 
 #if defined(__FreeBSD__) && (__FreeBSD_version >= 300000)
@@ -211,4 +172,6 @@ glibtop_get_netload_p (glibtop *server, glibtop_netload *buf,
 	ifnetaddr = (u_long) ifnet.if_list.tqe_next;
 #endif
     }
+
+    return 0;
 }
