@@ -1,3 +1,5 @@
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+
 /* $Id$ */
 
 /* Copyright (C) 1998 Joshua Sled
@@ -35,48 +37,52 @@ static const unsigned long _glibtop_sysdeps_proc_segment = 0;
 
 /* Init function. */
 
-void
+int
 glibtop_init_proc_segment_p (glibtop *server)
 {
-	server->sysdeps.proc_segment = _glibtop_sysdeps_proc_segment;
+    server->sysdeps.proc_segment = _glibtop_sysdeps_proc_segment;
+
+    return 0;
 }
 
 /* Provides detailed information about a process. */
 
-void
+int
 glibtop_get_proc_segment_p (glibtop *server,
 			    glibtop_proc_segment *buf,
 			    pid_t pid)
 {
-	glibtop_init_p (server, (1L << GLIBTOP_SYSDEPS_PROC_SEGMENT), 0);
+    glibtop_init_p (server, (1L << GLIBTOP_SYSDEPS_PROC_SEGMENT), 0);
 	
-	memset (buf, 0, sizeof (glibtop_proc_segment));
+    memset (buf, 0, sizeof (glibtop_proc_segment));
 
 #if 0
-	/* Get the process info from the kernel */
-	kvm_getprocs (server->machine.kd, KERN_PROC_PID, pid, count);
-	if (*count != 1) {
-		return; /* the zeroed-out buffer indicating no data */
-	}
+    /* Get the process info from the kernel */
+    kvm_getprocs (server->_priv->machine.kd, KERN_PROC_PID, pid, count);
+    if (*count != 1) {
+	return -1; /* the zeroed-out buffer indicating no data */
+    }
 
-	/* trs: text resident set size
-	   pinfo[0]->kp_eproc.e_xrssize;
-	*/
-	/* buf->trs = pinfo[0]->kp_eproc.e_xrssize; */
-	/* lrs: shared-lib resident set size
-	   ?  */
-	/* drs: data resident set size
-	   pinfo[0]->kp_eproc.e_vm.vm_map.vm_dsize;
-	*/
-	/* dt: dirty pages
-	 */
-	/* start_code: address of beginning of code segment
+    /* trs: text resident set size
+       pinfo[0]->kp_eproc.e_xrssize;
+    */
+    /* buf->trs = pinfo[0]->kp_eproc.e_xrssize; */
+    /* lrs: shared-lib resident set size
+       ?  */
+    /* drs: data resident set size
+       pinfo[0]->kp_eproc.e_vm.vm_map.vm_dsize;
+    */
+    /* dt: dirty pages
+     */
+    /* start_code: address of beginning of code segment
 	   
-	 */
-	/* end_code: address of end of code segment
-	 */
-	/* start_stack: address of the bottom of stack segment
-	 */
+     */
+    /* end_code: address of end of code segment
+     */
+    /* start_stack: address of the bottom of stack segment
+     */
 #endif
+
+    return 0;
 }
 
