@@ -1,4 +1,6 @@
-/* $Id: shm_limits.c,v 1.11 1999/05/06 21:33:59 martin Exp $ */
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+
+/* $Id$ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -30,16 +32,21 @@
 #if defined(__bsdi__) && (_BSDI_VERSION < 199700)
 /* Older versions of BSDI don't seem to have this. */
 
-void
+int
 glibtop_init_shm_limits_p (glibtop *server)
-{ }
+{
 
-void
+    return 0;
+}
+
+int
 glibtop_get_shm_limits_p (glibtop *server, glibtop_shm_limits *buf)
 {
-        glibtop_init_p (server, (1L << GLIBTOP_SYSDEPS_SHM_LIMITS), 0);
+    glibtop_init_p (server, (1L << GLIBTOP_SYSDEPS_SHM_LIMITS), 0);
 
-        memset (buf, 0, sizeof (glibtop_shm_limits));
+    memset (buf, 0, sizeof (glibtop_shm_limits));
+
+    return 0;
 }
 
 #else
@@ -56,9 +63,9 @@ glibtop_get_shm_limits_p (glibtop *server, glibtop_shm_limits *buf)
 #include <sys/shm.h>
 
 static unsigned long _glibtop_sysdeps_shm_limits =
-(1L << GLIBTOP_IPC_SHMMAX) + (1L << GLIBTOP_IPC_SHMMIN) +
-(1L << GLIBTOP_IPC_SHMMNI) + (1L << GLIBTOP_IPC_SHMSEG) +
-(1L << GLIBTOP_IPC_SHMALL);
+(1L << GLIBTOP_SHM_LIMITS_SHMMAX) + (1L << GLIBTOP_SHM_LIMITS_SHMMIN) +
+(1L << GLIBTOP_SHM_LIMITS_SHMMNI) + (1L << GLIBTOP_SHM_LIMITS_SHMSEG) +
+(1L << GLIBTOP_SHM_LIMITS_SHMALL);
 
 /* The values in this structure never change at runtime, so we only
  * read it once during initialization. We have to use the name `_shminfo'
@@ -67,48 +74,52 @@ static struct shminfo _shminfo;
   
 /* nlist structure for kernel access */
 static struct nlist nlst [] = {
-	{ "_shminfo" },
-	{ 0 }
+    { "_shminfo" },
+    { 0 }
 };
 
 /* Init function. */
 
-void
+int
 glibtop_init_shm_limits_p (glibtop *server)
 {
-	if (kvm_nlist (server->machine.kd, nlst) != 0) {
-		glibtop_warn_io_r (server, "kvm_nlist (shm_limits)");
-		return;
-	}
+    if (kvm_nlist (server->_priv->machine.kd, nlst) != 0) {
+	glibtop_warn_io_r (server, "kvm_nlist (shm_limits)");
+	return -1;
+    }
 	
-	if (kvm_read (server->machine.kd, nlst [0].n_value,
-		      &_shminfo, sizeof (_shminfo)) != sizeof (_shminfo)) {
-		glibtop_warn_io_r (server, "kvm_read (shminfo)");
-		return;
-	}
+    if (kvm_read (server->_priv->machine.kd, nlst [0].n_value,
+		  &_shminfo, sizeof (_shminfo)) != sizeof (_shminfo)) {
+	glibtop_warn_io_r (server, "kvm_read (shminfo)");
+	return -1;
+    }
 
-	server->sysdeps.shm_limits = _glibtop_sysdeps_shm_limits;
+    server->sysdeps.shm_limits = _glibtop_sysdeps_shm_limits;
+
+    return 0;
 }
 
 /* Provides information about sysv ipc limits. */
 
-void
+int
 glibtop_get_shm_limits_p (glibtop *server, glibtop_shm_limits *buf)
 {
-	glibtop_init_p (server, (1L << GLIBTOP_SYSDEPS_SHM_LIMITS), 0);
+    glibtop_init_p (server, (1L << GLIBTOP_SYSDEPS_SHM_LIMITS), 0);
 	
-	memset (buf, 0, sizeof (glibtop_shm_limits));
+    memset (buf, 0, sizeof (glibtop_shm_limits));
 
-	if (server->sysdeps.shm_limits == 0)
-		return;
+    if (server->sysdeps.shm_limits == 0)
+	return -1;
 
-	buf->shmmax = _shminfo.shmmax;
-	buf->shmmin = _shminfo.shmmin;
-	buf->shmmni = _shminfo.shmmni;
-	buf->shmseg = _shminfo.shmseg;
-	buf->shmall = _shminfo.shmall;
+    buf->shmmax = _shminfo.shmmax;
+    buf->shmmin = _shminfo.shmmin;
+    buf->shmmni = _shminfo.shmmni;
+    buf->shmseg = _shminfo.shmseg;
+    buf->shmall = _shminfo.shmall;
 
-	buf->flags = _glibtop_sysdeps_shm_limits;
+    buf->flags = _glibtop_sysdeps_shm_limits;
+
+    return 0;
 }
 
 #endif /* either a newer BSDI or no BSDI at all. */
