@@ -1,4 +1,6 @@
-/* $Id: cpu.c,v 1.11 1999/05/06 21:34:05 martin Exp $ */
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+
+/* $Id$ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -32,33 +34,36 @@ static const unsigned long _glibtop_sysdeps_cpu =
 (1L << GLIBTOP_CPU_IDLE) + (1L << GLIBTOP_CPU_FREQUENCY);
 
 static const unsigned long _glibtop_sysdeps_cpu_smp =
-(1L << GLIBTOP_XCPU_TOTAL) + (1L << GLIBTOP_XCPU_USER) +
-(1L << GLIBTOP_XCPU_NICE) + (1L << GLIBTOP_XCPU_SYS) +
-(1L << GLIBTOP_XCPU_IDLE);
+(1L << GLIBTOP_CPU_XCPU_TOTAL) + (1L << GLIBTOP_CPU_XCPU_USER) +
+(1L << GLIBTOP_CPU_XCPU_NICE) + (1L << GLIBTOP_CPU_XCPU_SYS) +
+(1L << GLIBTOP_CPU_XCPU_IDLE);
 
 /* Init function. */
 
-void
+int
 glibtop_init_cpu_s (glibtop *server)
 {
     server->sysdeps.cpu = _glibtop_sysdeps_cpu;
 
     if (server->ncpu)
 	server->sysdeps.cpu |= _glibtop_sysdeps_cpu_smp;
+
+    return 0;
 }
 
 /* Provides information about cpu usage. */
 
-void
+int
 glibtop_get_cpu_s (glibtop *server, glibtop_cpu *buf)
 {
     libgtop_stat_t stat;
-    int i;
+    int retval, i;
 
     memset (buf, 0, sizeof (glibtop_cpu));
 
-    if (glibtop_get_proc_data_stat_s (server, &stat))
-	return;
+    retval = glibtop_get_proc_data_stat_s (server, &stat);
+    if (retval)
+	return retval;
 
     buf->user = stat.cpu.user;
     buf->nice = stat.cpu.nice;
@@ -83,4 +88,6 @@ glibtop_get_cpu_s (glibtop *server, glibtop_cpu *buf)
 
 	buf->flags |= _glibtop_sysdeps_cpu_smp;
     }
+
+    return 0;
 }
