@@ -1,4 +1,6 @@
-/* $Id: loadavg.c,v 1.12 1999/05/06 21:34:06 martin Exp $ */
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+
+/* $Id$ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -31,27 +33,33 @@ static const unsigned long _glibtop_sysdeps_loadavg =
 
 /* Init function. */
 
-void
+int
 glibtop_init_loadavg_s (glibtop *server)
 {
     server->sysdeps.loadavg = _glibtop_sysdeps_loadavg;
+
+    return 0;
 }
 
 /* Provides load averange. */
 
-void
+int
 glibtop_get_loadavg_s (glibtop *server, glibtop_loadavg *buf)
 {
     libgtop_stat_t stat;
+    int retval;
 
     memset (buf, 0, sizeof (glibtop_loadavg));
 
-    if (glibtop_get_proc_data_stat_s (server, &stat))
-	return;
+    retval = glibtop_get_proc_data_stat_s (server, &stat);
+    if (retval)
+	return retval;
 
     buf->loadavg [0] = stat.loadavg [0];
     buf->loadavg [1] = stat.loadavg [1];
     buf->loadavg [2] = stat.loadavg [2];
 
     buf->flags = _glibtop_sysdeps_loadavg;
+
+    return 0;
 }
