@@ -1,4 +1,6 @@
-/* $Id: mem.c,v 1.11 1999/05/06 21:34:07 martin Exp $ */
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+
+/* $Id$ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -33,23 +35,27 @@ static const unsigned long _glibtop_sysdeps_mem =
 
 /* Init function. */
 
-void
+int
 glibtop_init_mem_s (glibtop *server)
 {
     server->sysdeps.mem = _glibtop_sysdeps_mem;
+
+    return 0;
 }
 
 /* Provides information about memory usage. */
 
-void
+int
 glibtop_get_mem_s (glibtop *server, glibtop_mem *buf)
 {
     libgtop_mem_t mem;
+    int retval;
 
     memset (buf, 0, sizeof (glibtop_mem));
 
-    if (glibtop_get_proc_data_mem_s (server, &mem))
-	return;
+    retval = glibtop_get_proc_data_mem_s (server, &mem);
+    if (retval)
+	return retval;
 
     buf->total = mem.totalram;
     buf->used = mem.totalram - mem.freeram;
@@ -59,4 +65,6 @@ glibtop_get_mem_s (glibtop *server, glibtop_mem *buf)
     buf->cached = mem.cachedram;
 
     buf->flags = _glibtop_sysdeps_mem;
+
+    return 0;
 }
