@@ -1,4 +1,6 @@
-/* $Id: msg_limits.c,v 1.10 1999/05/06 21:34:08 martin Exp $ */
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+
+/* $Id$ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -27,22 +29,24 @@
 #include <sys/msg.h>
 
 static const unsigned long _glibtop_sysdeps_msg_limits =
-(1L << GLIBTOP_IPC_MSGPOOL) + (1L << GLIBTOP_IPC_MSGMAP) +
-(1L << GLIBTOP_IPC_MSGMAX) + (1L << GLIBTOP_IPC_MSGMNB) +
-(1L << GLIBTOP_IPC_MSGMNI) + (1L << GLIBTOP_IPC_MSGSSZ) +
-(1L << GLIBTOP_IPC_MSGTQL);
+(1L << GLIBTOP_MSG_LIMITS_MSGPOOL) + (1L << GLIBTOP_MSG_LIMITS_MSGMAP) +
+(1L << GLIBTOP_MSG_LIMITS_MSGMAX) + (1L << GLIBTOP_MSG_LIMITS_MSGMNB) +
+(1L << GLIBTOP_MSG_LIMITS_MSGMNI) + (1L << GLIBTOP_MSG_LIMITS_MSGSSZ) +
+(1L << GLIBTOP_MSG_LIMITS_MSGTQL);
 
 /* Init function. */
 
-void
+int
 glibtop_init_msg_limits_s (glibtop *server)
 {
     server->sysdeps.msg_limits = _glibtop_sysdeps_msg_limits;
+
+    return 0;
 }
 
 /* Provides information about sysv ipc limits. */
 
-void
+int
 glibtop_get_msg_limits_s (glibtop *server, glibtop_msg_limits *buf)
 {
     struct msginfo msginfo;
@@ -53,7 +57,8 @@ glibtop_get_msg_limits_s (glibtop *server, glibtop_msg_limits *buf)
   
     buf->flags = _glibtop_sysdeps_msg_limits;
   
-    msgctl (0, IPC_INFO, (struct msqid_ds *) &msginfo);
+    if (msgctl (0, IPC_INFO, (struct msqid_ds *) &msginfo))
+	return -1;
   
     buf->msgpool = msginfo.msgpool;
     buf->msgmap = msginfo.msgmap;
@@ -62,4 +67,6 @@ glibtop_get_msg_limits_s (glibtop *server, glibtop_msg_limits *buf)
     buf->msgmni = msginfo.msgmni;
     buf->msgssz = msginfo.msgssz;
     buf->msgtql = msginfo.msgtql;
+
+    return 0;
 }
