@@ -1,4 +1,6 @@
-/* $Id: proclist.c,v 1.14 1999/05/06 21:34:13 martin Exp $ */
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+
+/* $Id$ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -35,10 +37,12 @@ static const unsigned long _glibtop_sysdeps_proclist =
 
 /* Init function. */
 
-void
+int
 glibtop_init_proclist_s (glibtop *server)
 {
     server->sysdeps.proclist = _glibtop_sysdeps_proclist;
+
+    return 0;
 }
 
 /* Fetch list of currently running processes.
