@@ -1,4 +1,6 @@
-/* $Id: procmem.c,v 1.13 1999/05/06 21:34:15 martin Exp $ */
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+
+/* $Id$ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -43,7 +45,7 @@ static int pageshift;		/* log base 2 of the pagesize */
 
 /* Init function. */
 
-void
+int
 glibtop_init_proc_mem_s (glibtop *server)
 {
     register int pagesize;
@@ -57,20 +59,24 @@ glibtop_init_proc_mem_s (glibtop *server)
 	pageshift++;
 	pagesize >>= 1;
     }
+
+    return 0;
 }
 
 /* Provides detailed information about a process. */
 
-void
+int
 glibtop_get_proc_mem_s (glibtop *server, glibtop_proc_mem *buf,
 			pid_t pid)
 {
     libgtop_proc_mem_t proc_mem;
+    int retval;
 
     memset (buf, 0, sizeof (glibtop_proc_mem));
 
-    if (glibtop_get_proc_data_proc_mem_s (server, &proc_mem, pid))
-	return;
+    retval = glibtop_get_proc_data_proc_mem_s (server, &proc_mem, pid);
+    if (retval)
+	return retval;
 
     buf->vsize = proc_mem.segment.vsize;
 
@@ -88,4 +94,6 @@ glibtop_get_proc_mem_s (glibtop *server, glibtop_proc_mem *buf,
     buf->share <<= pageshift;
 
     buf->flags = _glibtop_sysdeps_proc_mem;
+
+    return 0;
 }
