@@ -1,4 +1,6 @@
-/* $Id: procsegment.c,v 1.15 1999/05/06 21:34:16 martin Exp $ */
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+
+/* $Id$ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -50,7 +52,7 @@ static int pageshift;		/* log base 2 of the pagesize */
 
 /* Init function. */
 
-void
+int
 glibtop_init_proc_segment_s (glibtop *server)
 {
     register int pagesize;
@@ -65,21 +67,25 @@ glibtop_init_proc_segment_s (glibtop *server)
 	pageshift++;
 	pagesize >>= 1;
     }
+
+    return 0;
 }
 
 /* Provides detailed information about a process. */
 
-void
+int
 glibtop_get_proc_segment_s (glibtop *server, glibtop_proc_segment *buf,
 			    pid_t pid)
 {
     libgtop_proc_mem_t proc_mem;
     libgtop_proc_state_t proc_state;
+    int retval;
 
     memset (buf, 0, sizeof (glibtop_proc_segment));
 
-    if (glibtop_get_proc_data_proc_mem_s (server, &proc_mem, pid))
-	return;
+    retval = glibtop_get_proc_data_proc_mem_s (server, &proc_mem, pid);
+    if (retval)
+	return retval;
 
     buf->text_rss = proc_mem.trs;
     buf->shlib_rss = proc_mem.lrs;
@@ -95,8 +101,9 @@ glibtop_get_proc_segment_s (glibtop *server, glibtop_proc_segment *buf,
 
     buf->flags = _glibtop_sysdeps_proc_segment;
 
-    if (glibtop_get_proc_data_proc_state_s (server, &proc_state, pid))
-	return;
+    retval = glibtop_get_proc_data_proc_state_s (server, &proc_state, pid);
+    if (retval)
+	return retval;
 
     buf->start_code = proc_state.start_code;
     buf->end_code = proc_state.end_code;
@@ -114,4 +121,6 @@ glibtop_get_proc_segment_s (glibtop *server, glibtop_proc_segment *buf,
     buf->env_end = proc_state.env_end;
 
     buf->flags |= _glibtop_sysdeps_proc_segment_state;
+
+    return 0;
 }
