@@ -1,4 +1,6 @@
-/* $Id: procsignal.c,v 1.13 1999/05/06 21:34:17 martin Exp $ */
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+
+/* $Id$ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -34,25 +36,28 @@ static const unsigned long _glibtop_sysdeps_proc_signal =
 
 /* Init function. */
 
-void
+int
 glibtop_init_proc_signal_s (glibtop *server)
 {
     server->sysdeps.proc_signal = _glibtop_sysdeps_proc_signal;
+
+    return 0;
 }
 
 /* Provides detailed information about a process. */
 
-void
+int
 glibtop_get_proc_signal_s (glibtop *server, glibtop_proc_signal *buf,
 			   pid_t pid)
 {
     libgtop_proc_signal_t proc_signal;
-    int i;
+    int retval, i;
 
     memset (buf, 0, sizeof (glibtop_proc_signal));
 
-    if (glibtop_get_proc_data_proc_signal_s (server, &proc_signal, pid))
-	return;
+    retval = glibtop_get_proc_data_proc_signal_s (server, &proc_signal, pid);
+    if (retval)
+	return retval;
 
     for (i = 0; i < 1; i++) {
 	buf->signal [i] = proc_signal.signal [i];
@@ -62,4 +67,6 @@ glibtop_get_proc_signal_s (glibtop *server, glibtop_proc_signal *buf,
     }
 
     buf->flags = _glibtop_sysdeps_proc_signal;
+
+    return 0;
 }
