@@ -1,4 +1,6 @@
-/* $Id: procstate.c,v 1.13 1999/05/06 21:34:18 martin Exp $ */
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+
+/* $Id$ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -35,24 +37,28 @@ static const unsigned long _glibtop_sysdeps_proc_state =
 
 /* Init function. */
 
-void
+int
 glibtop_init_proc_state_s (glibtop *server)
 {
     server->sysdeps.proc_state = _glibtop_sysdeps_proc_state;
+
+    return 0;
 }
 
 /* Provides detailed information about a process. */
 
-void
+int
 glibtop_get_proc_state_s (glibtop *server, glibtop_proc_state *buf,
 			  pid_t pid)
 {
     libgtop_proc_state_t proc_state;
+    int retval;
 
     memset (buf, 0, sizeof (glibtop_proc_state));
 
-    if (glibtop_get_proc_data_proc_state_s (server, &proc_state, pid))
-	return;
+    retval = glibtop_get_proc_data_proc_state_s (server, &proc_state, pid);
+    if (retval)
+	return retval;
 
     memcpy (buf->cmd, proc_state.comm, sizeof (buf->cmd));
 
@@ -79,4 +85,6 @@ glibtop_get_proc_state_s (glibtop *server, glibtop_proc_state *buf,
     buf->last_processor = proc_state.last_processor;
 
     buf->flags = _glibtop_sysdeps_proc_state;
+
+    return 0;
 }
