@@ -1,4 +1,6 @@
-/* $Id: procuid.c,v 1.12 1999/05/06 21:34:20 martin Exp $ */
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+
+/* $Id$ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -43,26 +45,29 @@ static const unsigned long _glibtop_sysdeps_proc_uid =
 
 /* Init function. */
 
-void
+int
 glibtop_init_proc_uid_s (glibtop *server)
 {
     server->sysdeps.proc_uid = _glibtop_sysdeps_proc_uid;
+
+    return 0;
 }
 
 /* Provides detailed information about a process. */
 
-void
+int
 glibtop_get_proc_uid_s (glibtop *server, glibtop_proc_uid *buf,
 			pid_t pid)
 {
     libgtop_proc_state_t proc_state;
     long priority, nice;
-    int i;
+    int retval, i;
 
     memset (buf, 0, sizeof (glibtop_proc_uid));
 
-    if (glibtop_get_proc_data_proc_state_s (server, &proc_state, pid))
-	return;
+    retval = glibtop_get_proc_data_proc_state_s (server, &proc_state, pid);
+    if (retval)
+	return retval;
 
     buf->uid = proc_state.uid;
     buf->euid = proc_state.euid;
@@ -97,4 +102,6 @@ glibtop_get_proc_uid_s (glibtop *server, glibtop_proc_uid *buf,
 	buf->groups [i] = proc_state.groups [i];
 
     buf->flags = _glibtop_sysdeps_proc_uid;
+
+    return 0;
 }
