@@ -1,3 +1,5 @@
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+
 /* $Id$ */
 
 /* Copyright (C) 1998-99 Martin Baulig
@@ -32,24 +34,28 @@ static unsigned long _glibtop_sysdeps_uptime =
 
 /* Init function. */
 
-void
+int
 glibtop_init_uptime_s (glibtop *server)
 {
     server->sysdeps.uptime = _glibtop_sysdeps_uptime;
+
+    return 0;
 }
 
 /* Provides uptime and idle time. */
 
-void
+int
 glibtop_get_uptime_s (glibtop *server, glibtop_uptime *buf)
 {
     libgtop_stat_t stat;
     unsigned long total;
+    int retval;
 
     memset (buf, 0, sizeof (glibtop_uptime));
 
-    if (glibtop_get_proc_data_stat_s (server, &stat))
-	return;
+    retval = glibtop_get_proc_data_stat_s (server, &stat);
+    if (retval)
+	return retval;
 
     total = stat.cpu.user + stat.cpu.nice + stat.cpu.sys + stat.cpu.idle;
 
@@ -59,4 +65,6 @@ glibtop_get_uptime_s (glibtop *server, glibtop_uptime *buf)
     buf->boot_time = stat.boot_time;
 
     buf->flags = _glibtop_sysdeps_uptime;
+
+    return 0;
 }
