@@ -1,4 +1,6 @@
-/* $Id: shm_limits.c,v 1.9 1999/05/06 21:34:45 martin Exp $ */
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+
+/* $Id$ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -27,36 +29,40 @@
 #include <sys/shm.h>
 
 static unsigned long _glibtop_sysdeps_shm_limits =
-(1L << GLIBTOP_IPC_SHMMAX) + (1L << GLIBTOP_IPC_SHMMIN) +
-(1L << GLIBTOP_IPC_SHMMNI) + (1L << GLIBTOP_IPC_SHMSEG) +
-(1L << GLIBTOP_IPC_SHMALL);
+(1L << GLIBTOP_SHM_LIMITS_SHMMAX) + (1L << GLIBTOP_SHM_LIMITS_SHMMIN) +
+(1L << GLIBTOP_SHM_LIMITS_SHMMNI) + (1L << GLIBTOP_SHM_LIMITS_SHMSEG) +
+(1L << GLIBTOP_SHM_LIMITS_SHMALL);
 
 /* Init function. */
 
-void
+int
 glibtop_init_shm_limits_s (glibtop *server)
 {
-	server->sysdeps.shm_limits = _glibtop_sysdeps_shm_limits;
+    server->sysdeps.shm_limits = _glibtop_sysdeps_shm_limits;
+
+    return 0;
 }
 
 /* Provides information about sysv ipc limits. */
 
-void
+int
 glibtop_get_shm_limits_s (glibtop *server, glibtop_shm_limits *buf)
 {
-	struct shminfo	shminfo;
+    struct shminfo	shminfo;
   
-	glibtop_init_s (&server, GLIBTOP_SYSDEPS_SHM_LIMITS, 0);
+    glibtop_init_s (&server, GLIBTOP_SYSDEPS_SHM_LIMITS, 0);
 
-	memset (buf, 0, sizeof (glibtop_shm_limits));
+    memset (buf, 0, sizeof (glibtop_shm_limits));
   
-	buf->flags = _glibtop_sysdeps_shm_limits;
+    buf->flags = _glibtop_sysdeps_shm_limits;
   
-	shmctl (0, IPC_INFO, (struct shmid_ds *) &shminfo);
+    shmctl (0, IPC_INFO, (struct shmid_ds *) &shminfo);
   
-	buf->shmmax = shminfo.shmmax;
-	buf->shmmin = shminfo.shmmin;
-	buf->shmmni = shminfo.shmmni;
-	buf->shmseg = shminfo.shmseg;
-	buf->shmall = shminfo.shmall;
+    buf->shmmax = shminfo.shmmax;
+    buf->shmmin = shminfo.shmmin;
+    buf->shmmni = shminfo.shmmni;
+    buf->shmseg = shminfo.shmseg;
+    buf->shmall = shminfo.shmall;
+
+    return 0;
 }
