@@ -1,4 +1,6 @@
-/* $Id: loadavg.c,v 1.8 1999/05/06 21:34:52 martin Exp $ */
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+
+/* $Id$ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -30,44 +32,44 @@ static const unsigned long _glibtop_sysdeps_loadavg =
 
 /* Init function. */
 
-void
+int
 glibtop_init_loadavg_s (glibtop *server)
 {
-	server->sysdeps.loadavg = _glibtop_sysdeps_loadavg;
+    server->sysdeps.loadavg = _glibtop_sysdeps_loadavg;
 }
 
 /* Provides load averange. */
 
-void
+int
 glibtop_get_loadavg_s (glibtop *server, glibtop_loadavg *buf)
 {
-	struct tbl_loadavg loadavg;
-	int ret;
+    struct tbl_loadavg loadavg;
+    int ret;
 
-	glibtop_init_s (&server, GLIBTOP_SYSDEPS_LOADAVG, 0);
+    glibtop_init_s (&server, GLIBTOP_SYSDEPS_LOADAVG, 0);
 
-	memset (buf, 0, sizeof (glibtop_loadavg));
+    memset (buf, 0, sizeof (glibtop_loadavg));
 	
-	ret = table (TBL_LOADAVG, 0, (char *) &loadavg, 1,
-		     sizeof (struct tbl_loadavg)); 
+    ret = table (TBL_LOADAVG, 0, (char *) &loadavg, 1,
+		 sizeof (struct tbl_loadavg)); 
 
-	if (ret != 1) return;
+    if (ret != 1) return;
 
-	buf->flags = _glibtop_sysdeps_loadavg;
+    buf->flags = _glibtop_sysdeps_loadavg;
 		
-	if (loadavg.tl_lscale == 0) {
-		buf->loadavg [0] = loadavg.tl_avenrun.d [0];
-		buf->loadavg [1] = loadavg.tl_avenrun.d [1];
-		buf->loadavg [2] = loadavg.tl_avenrun.d [2];
-	} else {
-		buf->loadavg [0] = 
-			(double) loadavg.tl_avenrun.l [0] /
-			(double) loadavg.tl_mach_factor [0];
-		buf->loadavg [1] =
-			(double) loadavg.tl_avenrun.l [1] 
-			/ (double) loadavg.tl_mach_factor [1];
-		buf->loadavg [2] =
-			(double) loadavg.tl_avenrun.l [2] /
-			(double) loadavg.tl_mach_factor [2];
-	}
+    if (loadavg.tl_lscale == 0) {
+	buf->loadavg [0] = loadavg.tl_avenrun.d [0];
+	buf->loadavg [1] = loadavg.tl_avenrun.d [1];
+	buf->loadavg [2] = loadavg.tl_avenrun.d [2];
+    } else {
+	buf->loadavg [0] = 
+	    (double) loadavg.tl_avenrun.l [0] /
+	    (double) loadavg.tl_mach_factor [0];
+	buf->loadavg [1] =
+	    (double) loadavg.tl_avenrun.l [1] 
+	    / (double) loadavg.tl_mach_factor [1];
+	buf->loadavg [2] =
+	    (double) loadavg.tl_avenrun.l [2] /
+	    (double) loadavg.tl_mach_factor [2];
+    }
 }
