@@ -1,3 +1,5 @@
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+
 /* $Id$ */
 
 /* Copyright (C) 1998-99 Martin Baulig
@@ -30,10 +32,10 @@ static const unsigned long _glibtop_sysdeps_proc_args = 0;
 
 /* Init function. */
 
-void
+int
 glibtop_init_proc_args_p (glibtop *server)
 {
-	server->sysdeps.proc_args = _glibtop_sysdeps_proc_args;
+    server->sysdeps.proc_args = _glibtop_sysdeps_proc_args;
 }
 
 /* Provides detailed information about a process. */
@@ -42,6 +44,6 @@ char *
 glibtop_get_proc_args_p (glibtop *server, glibtop_proc_args *buf,
 			 pid_t pid, unsigned max_len)
 {
-	memset (buf, 0, sizeof (glibtop_proc_args));
-	return NULL;
+    memset (buf, 0, sizeof (glibtop_proc_args));
+    return NULL;
 }
