@@ -1,4 +1,6 @@
-/* $Id: procmem.c,v 1.8 1999/05/06 21:34:57 martin Exp $ */
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+
+/* $Id$ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -41,63 +43,63 @@ static const unsigned long _glibtop_sysdeps_proc_mem =
 
 /* Init function. */
 
-void
+int
 glibtop_init_proc_mem_p (glibtop *server)
 {
-	server->sysdeps.proc_mem = _glibtop_sysdeps_proc_mem;
+    server->sysdeps.proc_mem = _glibtop_sysdeps_proc_mem;
 }
 
 /* Provides detailed information about a process. */
 
-void
+int
 glibtop_get_proc_mem_p (glibtop *server, glibtop_proc_mem *buf,
 			pid_t pid)
 {
-	task_basic_info_data_t taskinfo;
-	int ret, info_count;
-	task_t thistask;
-	struct user u;
+    task_basic_info_data_t taskinfo;
+    int ret, info_count;
+    task_t thistask;
+    struct user u;
 
-	glibtop_init_p (server, GLIBTOP_SYSDEPS_PROC_MEM, 0);
+    glibtop_init_p (server, GLIBTOP_SYSDEPS_PROC_MEM, 0);
 	
-	memset (buf, 0, sizeof (glibtop_proc_mem));
+    memset (buf, 0, sizeof (glibtop_proc_mem));
 
-	/* Get task structure. */
+    /* Get task structure. */
 	
-	ret = task_by_unix_pid (task_self(), pid, &thistask);
+    ret = task_by_unix_pid (task_self(), pid, &thistask);
 	
-	if (ret != KERN_SUCCESS) return;
+    if (ret != KERN_SUCCESS) return;
 	
-	/* Get taskinfo about this task. */
+    /* Get taskinfo about this task. */
 	
-	info_count = TASK_BASIC_INFO_COUNT;
+    info_count = TASK_BASIC_INFO_COUNT;
 	
-	ret = task_info (thistask, TASK_BASIC_INFO,
-			 (task_info_t) &taskinfo, &info_count);
+    ret = task_info (thistask, TASK_BASIC_INFO,
+		     (task_info_t) &taskinfo, &info_count);
 	
-	if (ret != KERN_SUCCESS) return;
+    if (ret != KERN_SUCCESS) return;
 
-	buf->resident = taskinfo.resident_size;
-	buf->rss = taskinfo.resident_size;
-	buf->vsize = taskinfo.virtual_size;
+    buf->resident = taskinfo.resident_size;
+    buf->rss = taskinfo.resident_size;
+    buf->vsize = taskinfo.virtual_size;
 
-	/* !!! THE FOLLOWING CODE RUNS SUID ROOT - CHANGE WITH CAUTION !!! */
+    /* !!! THE FOLLOWING CODE RUNS SUID ROOT - CHANGE WITH CAUTION !!! */
 
-	glibtop_suid_enter (server);
+    glibtop_suid_enter (server);
 	
-	ret = table (TBL_UAREA, pid, (char *) &u, 1,
-		     sizeof (struct user));
+    ret = table (TBL_UAREA, pid, (char *) &u, 1,
+		 sizeof (struct user));
 
-	glibtop_suid_leave (server);
+    glibtop_suid_leave (server);
 		     
-	/* !!! END OF SUID ROOT PART !!! */
+    /* !!! END OF SUID ROOT PART !!! */
 	
-	if (ret != 1) return;
+    if (ret != 1) return;
 	
-	buf->rss_rlim = u.u_rlimit [RLIMIT_RSS].rlim_cur;
+    buf->rss_rlim = u.u_rlimit [RLIMIT_RSS].rlim_cur;
 
-	buf->share = u.u_ru.ru_ixrss;
+    buf->share = u.u_ru.ru_ixrss;
 
-	buf->flags |= (1L << GLIBTOP_PROC_MEM_RSS_RLIM) |
-		(1L << GLIBTOP_PROC_MEM_SHARE);
+    buf->flags |= (1L << GLIBTOP_PROC_MEM_RSS_RLIM) |
+	(1L << GLIBTOP_PROC_MEM_SHARE);
 }
