@@ -1,3 +1,5 @@
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+
 /* $Id$ */
 
 /* Copyright (C) 1998-99 Martin Baulig
@@ -37,44 +39,44 @@ static const unsigned long _glibtop_sysdeps_proc_segment =
 
 /* Init function. */
 
-void
+int
 glibtop_init_proc_segment_p (glibtop *server)
 {
-	server->sysdeps.proc_segment = _glibtop_sysdeps_proc_segment;
+    server->sysdeps.proc_segment = _glibtop_sysdeps_proc_segment;
 }
 
 /* Provides detailed information about a process. */
 
-void
+int
 glibtop_get_proc_segment_p (glibtop *server, glibtop_proc_segment *buf,
 			    pid_t pid)
 {
-	int ret;
-	struct user u;
+    int ret;
+    struct user u;
 
-	glibtop_init_p (server, GLIBTOP_SYSDEPS_PROC_SEGMENT, 0);
+    glibtop_init_p (server, GLIBTOP_SYSDEPS_PROC_SEGMENT, 0);
 	
-	memset (buf, 0, sizeof (glibtop_proc_segment));
+    memset (buf, 0, sizeof (glibtop_proc_segment));
 
-	/* !!! THE FOLLOWING CODE RUNS SUID ROOT - CHANGE WITH CAUTION !!! */
+    /* !!! THE FOLLOWING CODE RUNS SUID ROOT - CHANGE WITH CAUTION !!! */
 
-	glibtop_suid_enter (server);
+    glibtop_suid_enter (server);
 	
-	ret = table (TBL_UAREA, pid, (char *) &u, 1,
-		     sizeof (struct user));
+    ret = table (TBL_UAREA, pid, (char *) &u, 1,
+		 sizeof (struct user));
 
-	glibtop_suid_leave (server);
+    glibtop_suid_leave (server);
 		     
-	/* !!! END OF SUID ROOT PART !!! */
+    /* !!! END OF SUID ROOT PART !!! */
 	
-	if (ret != 1) return;
+    if (ret != 1) return;
 	
-	buf->start_code = (unsigned long) u.u_text_start;
-	buf->end_code = (unsigned long) u.u_data_start;
-	buf->start_stack = (unsigned long) u.u_stack_start;
+    buf->start_code = (unsigned long) u.u_text_start;
+    buf->end_code = (unsigned long) u.u_data_start;
+    buf->start_stack = (unsigned long) u.u_stack_start;
 	
-	buf->text_rss = u.u_tsize;
-	buf->data_rss = u.u_dsize;
+    buf->text_rss = u.u_tsize;
+    buf->data_rss = u.u_dsize;
 	
-	buf->flags = _glibtop_sysdeps_proc_segment;
+    buf->flags = _glibtop_sysdeps_proc_segment;
 }
