@@ -1,3 +1,5 @@
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+
 /* $Id$ */
 
 /* Copyright (C) 1998-99 Martin Baulig
@@ -36,44 +38,44 @@ static const unsigned long _glibtop_sysdeps_proc_time =
 
 /* Init function. */
 
-void
+int
 glibtop_init_proc_time_p (glibtop *server)
 {
-	server->sysdeps.proc_time = _glibtop_sysdeps_proc_time;
+    server->sysdeps.proc_time = _glibtop_sysdeps_proc_time;
 }
 
 /* Provides detailed information about a process. */
 
-void
+int
 glibtop_get_proc_time_p (glibtop *server, glibtop_proc_time *buf,
 			 pid_t pid)
 {
-	struct user u;
-	int ret;
+    struct user u;
+    int ret;
 
-	glibtop_init_p (server, GLIBTOP_SYSDEPS_PROC_TIME, 0);
+    glibtop_init_p (server, GLIBTOP_SYSDEPS_PROC_TIME, 0);
 	
-	memset (buf, 0, sizeof (glibtop_proc_time));
+    memset (buf, 0, sizeof (glibtop_proc_time));
 	
-	/* !!! THE FOLLOWING CODE RUNS SUID ROOT - CHANGE WITH CAUTION !!! */
+    /* !!! THE FOLLOWING CODE RUNS SUID ROOT - CHANGE WITH CAUTION !!! */
 
-	glibtop_suid_enter (server);
+    glibtop_suid_enter (server);
 	
-	ret = table (TBL_UAREA, pid, (char *) &u, 1,
-		     sizeof (struct user));
+    ret = table (TBL_UAREA, pid, (char *) &u, 1,
+		 sizeof (struct user));
 		     
-	glibtop_suid_leave (server);
+    glibtop_suid_leave (server);
 		     
-	/* !!! END OF SUID ROOT PART !!! */
+    /* !!! END OF SUID ROOT PART !!! */
 	
-	if (ret != 1) return;
+    if (ret != 1) return;
 
-	buf->start_time = u.u_start.tv_sec;
+    buf->start_time = u.u_start.tv_sec;
 	
-	buf->utime = u.u_ru.ru_utime.tv_sec;
-	buf->stime = u.u_ru.ru_stime.tv_sec;
-	buf->cutime = u.u_cru.ru_utime.tv_sec;
-	buf->cstime = u.u_cru.ru_stime.tv_sec;
+    buf->utime = u.u_ru.ru_utime.tv_sec;
+    buf->stime = u.u_ru.ru_stime.tv_sec;
+    buf->cutime = u.u_cru.ru_utime.tv_sec;
+    buf->cstime = u.u_cru.ru_stime.tv_sec;
 
-	buf->flags = _glibtop_sysdeps_proc_time;	
+    buf->flags = _glibtop_sysdeps_proc_time;	
 }
