@@ -1,4 +1,6 @@
-/* $Id: swap.c,v 1.8 1999/05/06 21:35:06 martin Exp $ */
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+
+/* $Id$ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -31,34 +33,34 @@ static unsigned long _glibtop_sysdeps_swap =
 
 /* Init function. */
 
-void
+int
 glibtop_init_swap_s (glibtop *server)
 {
-	server->sysdeps.swap = _glibtop_sysdeps_swap;
+    server->sysdeps.swap = _glibtop_sysdeps_swap;
 }
 
 /* Provides information about swap usage. */
 
-void
+int
 glibtop_get_swap_s (glibtop *server, glibtop_swap *buf)
 {
-	struct tbl_swapinfo swapinfo;
-	int i;
+    struct tbl_swapinfo swapinfo;
+    int i;
 
-	glibtop_init_s (&server, GLIBTOP_SYSDEPS_SWAP, 0);
+    glibtop_init_s (&server, GLIBTOP_SYSDEPS_SWAP, 0);
 
-	memset (buf, 0, sizeof (glibtop_swap));
+    memset (buf, 0, sizeof (glibtop_swap));
 
-	i = 0;
+    i = 0;
 	
-	while (table (TBL_SWAPINFO, i, (char *) &swapinfo, 1,
-		      sizeof (struct tbl_swapinfo)) > 0) {
-		buf->total += swapinfo.size * getpagesize ();
-		buf->free  += swapinfo.free * getpagesize ();
-		i++;
-	}
+    while (table (TBL_SWAPINFO, i, (char *) &swapinfo, 1,
+		  sizeof (struct tbl_swapinfo)) > 0) {
+	buf->total += swapinfo.size * getpagesize ();
+	buf->free  += swapinfo.free * getpagesize ();
+	i++;
+    }
 
-	buf->flags = _glibtop_sysdeps_swap;
+    buf->flags = _glibtop_sysdeps_swap;
 	
-	buf->used  = buf->total - buf->free;
+    buf->used  = buf->total - buf->free;
 }
