@@ -1,4 +1,6 @@
-/* $Id: glibtop_server.h,v 1.2 1999/05/07 23:24:04 martin Exp $ */
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+
+/* $Id$ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -45,6 +47,7 @@ BEGIN_LIBGTOP_DECLS
 #define GLIBTOP_SUID_PROC_ARGS		0
 #define GLIBTOP_SUID_PROC_MAP		0
 #define GLIBTOP_SUID_NETLOAD		0
+#define GLIBTOP_SUID_INTERFACE_NAMES	0
 #define GLIBTOP_SUID_PPP		0
 
 END_LIBGTOP_DECLS
