@@ -1,4 +1,6 @@
-/* $Id: mem.c,v 1.6 1999/05/09 22:38:16 dave Exp $ */
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+
+/* $Id$ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -40,22 +42,24 @@ static const unsigned long _glibtop_sysdeps_mem_bunyip =
 
 /* Init function. */
 
-void
+int
 glibtop_init_mem_s (glibtop *server)
 {
     server->sysdeps.mem = _glibtop_sysdeps_mem_os_sysconf +
         _glibtop_sysdeps_mem_os_kstat + _glibtop_sysdeps_mem_bunyip;
+
+    return 0;
 }
 
 /* Provides information about memory usage. */
 
-void
+int
 glibtop_get_mem_s (glibtop *server, glibtop_mem *buf)
 {
-    kstat_ctl_t *kc = server->machine.kc; 
+    kstat_ctl_t *kc = server->_priv->machine.kc; 
     kstat_t *ksp;
     kstat_named_t *kn;
-    int pagesize = server->machine.pagesize;
+    int pagesize = server->_priv->machine.pagesize;
 
 #ifndef KSTAT_DATA_UINT32
 #define ui32 ul
@@ -67,61 +71,63 @@ glibtop_get_mem_s (glibtop *server, glibtop_mem *buf)
     buf->flags = _glibtop_sysdeps_mem_os_sysconf;
 
     if(!kc)
-        return;
+        return -GLIBTOP_ERROR_INCOMPATIBLE_KERNEL;
     switch(kstat_chain_update(kc))
-    {
+	{
         case -1: assert(0);  /* Debugging purposes, shouldn't happen */
 	case 0:  break;
 	default: glibtop_get_kstats(server);
-    }
-
-    if((ksp = server->machine.syspages) && kstat_read(kc, ksp, NULL) >= 0)
-    {
-	kn = (kstat_named_t *)kstat_data_lookup(ksp, "pagesfree");
-	if(kn)
-	{
-#ifdef _LP64
-	    buf->free = kn->value.ui64 << pagesize << 10;
-#else
-	    buf->free = kn->value.ui32 << pagesize << 10;
-#endif
-	    buf->used = buf->total - buf->free;
 	}
-	kn = (kstat_named_t *)kstat_data_lookup(ksp, "pageslocked");
-	if(kn)
+
+    if((ksp = server->_priv->machine.syspages) && kstat_read(kc, ksp, NULL) >= 0)
+	{
+	    kn = (kstat_named_t *)kstat_data_lookup(ksp, "pagesfree");
+	    if(kn)
+		{
 #ifdef _LP64
-	    buf->locked = kn->value.ui64 << pagesize;
+		    buf->free = kn->value.ui64 << pagesize << 10;
+#else
+		    buf->free = kn->value.ui32 << pagesize << 10;
+#endif
+		    buf->used = buf->total - buf->free;
+		}
+	    kn = (kstat_named_t *)kstat_data_lookup(ksp, "pageslocked");
+	    if(kn)
+#ifdef _LP64
+		buf->locked = kn->value.ui64 << pagesize;
 #else
 	    buf->locked = kn->value.ui32 << pagesize;
 #endif
-	buf->flags += _glibtop_sysdeps_mem_os_kstat;
-    }
+	    buf->flags += _glibtop_sysdeps_mem_os_kstat;
+	}
 
     /* Bunyip module provides data in multiples of system page size */
 
-    if((ksp = server->machine.bunyip) && kstat_read(kc, ksp, NULL) >= 0)
-    {
-        kn = (kstat_named_t *)kstat_data_lookup(ksp, "pages_anon");
-	if(kn)
+    if((ksp = server->_priv->machine.bunyip) && kstat_read(kc, ksp, NULL) >= 0)
+	{
+	    kn = (kstat_named_t *)kstat_data_lookup(ksp, "pages_anon");
+	    if(kn)
 #ifdef _LP64
-	    buf->user = kn->value.ui64 << pagesize << 10;
+		buf->user = kn->value.ui64 << pagesize << 10;
 #else
 	    buf->user = kn->value.ui32 << pagesize << 10;
 #endif
-	kn = (kstat_named_t *)kstat_data_lookup(ksp, "pages_exec");
-	if(kn)
+	    kn = (kstat_named_t *)kstat_data_lookup(ksp, "pages_exec");
+	    if(kn)
 #ifdef _LP64
-	    buf->shared = kn->value.ui64 << pagesize << 10;
+		buf->shared = kn->value.ui64 << pagesize << 10;
 #else
 	    buf->shared = kn->value.ui32 << pagesize << 10;
 #endif
-	kn = (kstat_named_t *)kstat_data_lookup(ksp, "pages_vnode");
-	if(kn)
+	    kn = (kstat_named_t *)kstat_data_lookup(ksp, "pages_vnode");
+	    if(kn)
 #ifdef _LP64
-	    buf->buffer = kn->value.ui64 << pagesize << 10;
+		buf->buffer = kn->value.ui64 << pagesize << 10;
 #else
 	    buf->buffer = kn->value.ui32 << pagesize << 10;
 #endif
-	buf->flags += _glibtop_sysdeps_mem_bunyip;
-    }
+	    buf->flags += _glibtop_sysdeps_mem_bunyip;
+	}
+
+    return 0;
 }
