@@ -1,4 +1,6 @@
-/* $Id: netload.c,v 1.1.1.1 1999/03/17 18:29:39 martin Exp $ */
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+
+/* $Id$ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -29,17 +31,22 @@ static const unsigned long _glibtop_sysdeps_netload = 0;
 
 /* Init function. */
 
-void
+int
 glibtop_init_netload_s (glibtop *server)
 {
-	server->sysdeps.netload = _glibtop_sysdeps_netload;
+    server->sysdeps.netload = _glibtop_sysdeps_netload;
+
+    return 0;
 }
 
 /* Provides network statistics. */
 
-void
+int
 glibtop_get_netload_s (glibtop *server, glibtop_netload *buf,
-		       const char *interface)
+		       const char *interface, unsigned transport,
+		       unsigned protocol)
 {
-	memset (buf, 0, sizeof (glibtop_netload));
+    memset (buf, 0, sizeof (glibtop_netload));
+
+    return 0;
 }
