@@ -1,3 +1,5 @@
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+
 /* $Id$ */
 
 /* Copyright (C) 1998-99 Martin Baulig
@@ -28,16 +30,20 @@ static const unsigned long _glibtop_sysdeps_cpu = 0;
 
 /* Init function. */
 
-void
+int
 glibtop_init_cpu_s (glibtop *server)
 {
-	server->sysdeps.cpu = _glibtop_sysdeps_cpu;
+    server->sysdeps.cpu = _glibtop_sysdeps_cpu;
+
+    return 0;
 }
 
 /* Provides information about cpu usage. */
 
-void
+int
 glibtop_get_cpu_s (glibtop *server, glibtop_cpu *buf)
 {
-	memset (buf, 0, sizeof (glibtop_cpu));
+    memset (buf, 0, sizeof (glibtop_cpu));
+
+    return 0;
 }
