@@ -1,3 +1,5 @@
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+
 /* $Id$ */
 
 /* Copyright (C) 1998-99 Martin Baulig
@@ -28,16 +30,20 @@ static const unsigned long _glibtop_sysdeps_mem = 0;
 
 /* Init function. */
 
-void
+int
 glibtop_init_mem_s (glibtop *server)
 {
-	server->sysdeps.mem = _glibtop_sysdeps_mem;
+    server->sysdeps.mem = _glibtop_sysdeps_mem;
+
+    return 0;
 }
 
 /* Provides information about memory usage. */
 
-void
+int
 glibtop_get_mem_s (glibtop *server, glibtop_mem *buf)
 {
-	memset (buf, 0, sizeof (glibtop_mem));
+    memset (buf, 0, sizeof (glibtop_mem));
+
+    return 0;
 }
