@@ -1,3 +1,5 @@
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+
 /* $Id$ */
 
 /* Copyright (C) 1998-99 Martin Baulig
@@ -30,10 +32,12 @@ static const unsigned long _glibtop_sysdeps_proclist = 0;
 
 /* Init function. */
 
-void
+int
 glibtop_init_proclist_s (glibtop *server)
 {
-	server->sysdeps.proclist = _glibtop_sysdeps_proclist;
+    server->sysdeps.proclist = _glibtop_sysdeps_proclist;
+
+    return 0;
 }
 
 /* Fetch list of currently running processes.
@@ -47,6 +51,6 @@ unsigned *
 glibtop_get_proclist_s (glibtop *server, glibtop_proclist *buf,
 			int64_t which, int64_t arg)
 {
-	memset (buf, 0, sizeof (glibtop_proclist));
-	return NULL;
+    memset (buf, 0, sizeof (glibtop_proclist));
+    return NULL;
 }
