@@ -1,3 +1,5 @@
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+
 /* $Id$ */
 
 /* Copyright (C) 1998-99 Martin Baulig
@@ -28,16 +30,20 @@ static const unsigned long _glibtop_sysdeps_sem_limits = 0;
 
 /* Init function. */
 
-void
+int
 glibtop_init_sem_limits_s (glibtop *server)
 {
-	server->sysdeps.sem_limits = _glibtop_sysdeps_sem_limits;
+    server->sysdeps.sem_limits = _glibtop_sysdeps_sem_limits;
+
+    return 0;
 }
 
 /* Provides information about sysv sem limits. */
 
-void
+int
 glibtop_get_sem_limits_s (glibtop *server, glibtop_sem_limits *buf)
 {
-	memset (buf, 0, sizeof (glibtop_sem_limits));
+    memset (buf, 0, sizeof (glibtop_sem_limits));
+
+    return 0;
 }
