@@ -1,3 +1,5 @@
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+
 /* $Id$ */
 
 /* Copyright (C) 1998-99 Martin Baulig
@@ -31,18 +33,22 @@ static const unsigned long _glibtop_sysdeps_cpu = 0;
 
 /* Init function. */
 
-void
+int
 glibtop_init_cpu_p (glibtop *server)
 {
-	server->sysdeps.cpu = _glibtop_sysdeps_cpu;
+    server->sysdeps.cpu = _glibtop_sysdeps_cpu;
+
+    return 0;
 }
 
 /* Provides information about cpu usage. */
 
-void
+int
 glibtop_get_cpu_p (glibtop *server, glibtop_cpu *buf)
 {
-	glibtop_init_p (server, GLIBTOP_SYSDEPS_CPU, 0);
+    glibtop_init_p (server, GLIBTOP_SYSDEPS_CPU, 0);
 	
-	memset (buf, 0, sizeof (glibtop_cpu));
+    memset (buf, 0, sizeof (glibtop_cpu));
+
+    return 0;
 }
