@@ -1,3 +1,5 @@
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+
 /* $Id$ */
 
 /* Copyright (C) 1998-99 Martin Baulig
@@ -25,21 +27,30 @@
 #include <glibtop/error.h>
 #include <glibtop/netload.h>
 
+#include <glibtop_suid.h>
+
 static const unsigned long _glibtop_sysdeps_netload = 0;
 
 /* Init function. */
 
-void
+int
 glibtop_init_netload_p (glibtop *server)
 {
-	server->sysdeps.netload = _glibtop_sysdeps_netload;
+    server->sysdeps.netload = _glibtop_sysdeps_netload;
+
+    return 0;
 }
 
 /* Provides Network statistics. */
 
-void
+int
 glibtop_get_netload_p (glibtop *server, glibtop_netload *buf,
-		       const char *interface)
+		       const char *interface, unsigned transport,
+		       unsigned protocol)
 {
-	memset (buf, 0, sizeof (glibtop_netload));
+    glibtop_init_p (server, GLIBTOP_SYSDEPS_NETLOAD, 0);
+	
+    memset (buf, 0, sizeof (glibtop_netload));
+
+    return 0;
 }
