@@ -1,3 +1,5 @@
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+
 /* $Id$ */
 
 /* Copyright (C) 1998-99 Martin Baulig
@@ -25,20 +27,28 @@
 #include <glibtop/error.h>
 #include <glibtop/ppp.h>
 
+#include <glibtop_suid.h>
+
 static const unsigned long _glibtop_sysdeps_ppp = 0;
 
 /* Init function. */
 
-void
+int
 glibtop_init_ppp_p (glibtop *server)
 {
-	server->sysdeps.ppp = _glibtop_sysdeps_ppp;
+    server->sysdeps.ppp = _glibtop_sysdeps_ppp;
+
+    return 0;
 }
 
 /* Provides PPP/ISDN information. */
 
-void
+int
 glibtop_get_ppp_p (glibtop *server, glibtop_ppp *buf, unsigned short device)
 {
-	memset (buf, 0, sizeof (glibtop_ppp));
+    glibtop_init_p (server, GLIBTOP_SYSDEPS_PPP, 0);
+	
+    memset (buf, 0, sizeof (glibtop_ppp));
+
+    return 0;
 }
