@@ -1,3 +1,5 @@
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+
 /* $Id$ */
 
 /* Copyright (C) 1998-99 Martin Baulig
@@ -30,10 +32,12 @@ static const unsigned long _glibtop_sysdeps_proc_map = 0;
 
 /* Init function. */
 
-void
+int
 glibtop_init_proc_map_p (glibtop *server)
 {
-	server->sysdeps.proc_map = _glibtop_sysdeps_proc_map;
+    server->sysdeps.proc_map = _glibtop_sysdeps_proc_map;
+
+    return 0;
 }
 
 /* Provides detailed information about a process. */
@@ -41,6 +45,6 @@ glibtop_init_proc_map_p (glibtop *server)
 glibtop_map_entry *
 glibtop_get_proc_map_p (glibtop *server, glibtop_proc_map *buf,	pid_t pid)
 {
-	memset (buf, 0, sizeof (glibtop_proc_map));
-	return NULL;
+    memset (buf, 0, sizeof (glibtop_proc_map));
+    return NULL;
 }
