@@ -1,4 +1,6 @@
-/* $Id: procmem.c,v 1.9 1999/05/06 21:35:26 martin Exp $ */
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+
+/* $Id$ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -32,32 +34,32 @@ static const unsigned long _glibtop_sysdeps_proc_mem =
 
 /* Provides detailed information about a process. */
 
-void
+int
 glibtop_get_proc_mem_p (glibtop *server, glibtop_proc_mem *buf,
 			pid_t pid)
 {
-	struct proc *pp;
+    struct proc *pp;
 
-	glibtop_init_p (server, (1L << GLIBTOP_SYSDEPS_PROC_MEM), 0);
+    glibtop_init_p (server, (1L << GLIBTOP_SYSDEPS_PROC_MEM), 0);
 
-	memset (buf, 0, sizeof (glibtop_proc_mem));
+    memset (buf, 0, sizeof (glibtop_proc_mem));
 
-	/* Read process table from kernel. */	
+    /* Read process table from kernel. */	
 
-	_glibtop_read_proc_table (server);
+    _glibtop_read_proc_table (server);
 
-	/* Find the pid in the process table. */
+    /* Find the pid in the process table. */
 
-	pp = _glibtop_find_pid (server, pid);
+    pp = _glibtop_find_pid (server, pid);
 
-	if (pp == NULL)	return;
+    if (pp == NULL)	return;
 
-	/* Fill in data fields. */
+    /* Fill in data fields. */
 
-	buf->size = (pp)->p_tsize + (pp)->p_dsize + (pp)->p_ssize;
+    buf->size = (pp)->p_tsize + (pp)->p_dsize + (pp)->p_ssize;
 
-	buf->rss = pp->p_rssize;
-	buf->rss_rlim = pp->p_maxrss;
+    buf->rss = pp->p_rssize;
+    buf->rss_rlim = pp->p_maxrss;
 
-	buf->flags = _glibtop_sysdeps_proc_mem;
+    buf->flags = _glibtop_sysdeps_proc_mem;
 }
