@@ -1,4 +1,6 @@
-/* $Id: procstate.c,v 1.9 1999/05/06 21:35:29 martin Exp $ */
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+
+/* $Id$ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -31,30 +33,30 @@ static const unsigned long _glibtop_sysdeps_proc_state =
 
 /* Provides detailed information about a process. */
 
-void
+int
 glibtop_get_proc_state_p (glibtop *server, glibtop_proc_state *buf,
 			  pid_t pid)
 {
-	struct proc *pp;
+    struct proc *pp;
 
-	glibtop_init_p (server, (1L << GLIBTOP_SYSDEPS_PROC_STATE), 0);
+    glibtop_init_p (server, (1L << GLIBTOP_SYSDEPS_PROC_STATE), 0);
 
-	memset (buf, 0, sizeof (glibtop_proc_state));
+    memset (buf, 0, sizeof (glibtop_proc_state));
 
-	/* Read process table from kernel. */	
+    /* Read process table from kernel. */	
 
-	_glibtop_read_proc_table (server);
+    _glibtop_read_proc_table (server);
 
-	/* Find the pid in the process table. */
+    /* Find the pid in the process table. */
 
-	pp = _glibtop_find_pid (server, pid);
+    pp = _glibtop_find_pid (server, pid);
 
-	if (pp == NULL)	return;
+    if (pp == NULL)	return;
 
-	/* Fill in data fields. */
+    /* Fill in data fields. */
 
-	buf->state = pp->p_stat;
-	buf->uid = pp->p_uid;
+    buf->state = pp->p_stat;
+    buf->uid = pp->p_uid;
 
-	buf->flags = _glibtop_sysdeps_proc_state;
+    buf->flags = _glibtop_sysdeps_proc_state;
 }
