@@ -1,4 +1,6 @@
-/* $Id: shm_limits.c,v 1.9 1999/05/06 21:35:34 martin Exp $ */
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+
+/* $Id$ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -34,41 +36,41 @@
 #include <sys/shm.h>
 
 static unsigned long _glibtop_sysdeps_shm_limits =
-(1L << GLIBTOP_IPC_SHMMAX) + (1L << GLIBTOP_IPC_SHMMIN) +
-(1L << GLIBTOP_IPC_SHMMNI) + (1L << GLIBTOP_IPC_SHMSEG) +
-(1L << GLIBTOP_IPC_SHMALL);
+(1L << GLIBTOP_SHM_LIMITS_SHMMAX) + (1L << GLIBTOP_SHM_LIMITS_SHMMIN) +
+(1L << GLIBTOP_SHM_LIMITS_SHMMNI) + (1L << GLIBTOP_SHM_LIMITS_SHMSEG) +
+(1L << GLIBTOP_SHM_LIMITS_SHMALL);
 
 /* Provides information about sysv ipc limits. */
 
-void
+int
 glibtop_get_shm_limits_p (glibtop *server, glibtop_shm_limits *buf)
 {
-	struct shminfo	shminfo;
+    struct shminfo	shminfo;
   
-	glibtop_init_p (server, (1L << GLIBTOP_SYSDEPS_SHM_LIMITS), 0);
+    glibtop_init_p (server, (1L << GLIBTOP_SYSDEPS_SHM_LIMITS), 0);
 
-	memset (buf, 0, sizeof (glibtop_shm_limits));
+    memset (buf, 0, sizeof (glibtop_shm_limits));
   
-	/* !!! THE FOLLOWING CODE RUNS SGID KMEM - CHANGE WITH CAUTION !!! */
+    /* !!! THE FOLLOWING CODE RUNS SGID KMEM - CHANGE WITH CAUTION !!! */
 	
-	setregid (server->machine.gid, server->machine.egid);
+    setregid (server->machine.gid, server->machine.egid);
 	
-	/* get the load average array */
+    /* get the load average array */
 
-	(void) _glibtop_getkval (server, _glibtop_nlist [X_SHMINFO].n_value,
-				 (int *) &shminfo, sizeof (shminfo),
-				 _glibtop_nlist [X_SHMINFO].n_name);
+    (void) _glibtop_getkval (server, _glibtop_nlist [X_SHMINFO].n_value,
+			     (int *) &shminfo, sizeof (shminfo),
+			     _glibtop_nlist [X_SHMINFO].n_name);
 
-	if (setregid (server->machine.egid, server->machine.gid))
-		_exit (1);
+    if (setregid (server->machine.egid, server->machine.gid))
+	_exit (1);
 	
-	/* !!! END OF SGID KMEM PART !!! */
+    /* !!! END OF SGID KMEM PART !!! */
 
-  	buf->shmmax = shminfo.shmmax;
-	buf->shmmin = shminfo.shmmin;
-	buf->shmmni = shminfo.shmmni;
-	buf->shmseg = shminfo.shmseg;
-	buf->shmall = shminfo.shmall;
+    buf->shmmax = shminfo.shmmax;
+    buf->shmmin = shminfo.shmmin;
+    buf->shmmni = shminfo.shmmni;
+    buf->shmseg = shminfo.shmseg;
+    buf->shmall = shminfo.shmall;
 
-	buf->flags = _glibtop_sysdeps_shm_limits;
+    buf->flags = _glibtop_sysdeps_shm_limits;
 }
