@@ -1,4 +1,6 @@
-/* $Id: swap.c,v 1.9 1999/05/06 21:35:35 martin Exp $ */
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+
+/* $Id$ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -28,10 +30,10 @@
 
 /* Provides information about swap usage. */
 
-void
+int
 glibtop_get_swap_p (glibtop *server, glibtop_swap *buf)
 {
-	glibtop_init_p (server, (1L << GLIBTOP_SYSDEPS_SWAP), 0);
+    glibtop_init_p (server, (1L << GLIBTOP_SYSDEPS_SWAP), 0);
 
-	memset (buf, 0, sizeof (glibtop_swap));
+    memset (buf, 0, sizeof (glibtop_swap));
 }
